@@ -38,6 +38,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
+#include <math.h>
 
 #include "Gdraws0.h"
 #include "G.h"
@@ -51,16 +52,44 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * Given 2 file pointers, this function copies file ifp to file ofp
  */
 
+#define BUFFER_SIZE 4096
+
 static void
 filecopy(FILE * ifp, FILE * ofp)
 {
-
-  int c;
-
-  while ((c = getc(ifp)) != EOF)
-    putc(c, ofp);
+  size_t bytesRead;
+  char buffer[BUFFER_SIZE];
+  while ((bytesRead = fread(buffer, 1, BUFFER_SIZE, ifp)) > 0) {
+      fwrite(buffer, 1, bytesRead, ofp);
+  }
 }
 
+/*
+ * Gdraws_computeScale calculates a scale factor based on the
+ * dimensions of the picture and page size.
+ */
+
+float Gdraws_computeScale(Window vw, Window tw) {
+  XWindowAttributes twInfo;
+  float pageWidth, pageHeight, scale;
+
+  XGetWindowAttributes(dsply, tw, &twInfo);
+  pageWidth = 575.0;
+  pageHeight = 750.0;
+#if 0
+  pageWidth = (float) (DisplayWidth(dsply, scrn) / DisplayWidthMM(dsply, scrn));
+  pageWidth *= 160.0;
+  pageHeight = (float) (DisplayHeight(dsply, scrn) / DisplayHeightMM(dsply, scrn));
+  pageHeight *= 210.0;
+  fprintf(stderr, "%f, %f\n", pageWidth, pageHeight);
+#endif
+  if ((twInfo.width > pageWidth) || (twInfo.height > pageHeight)) {
+    scale = fminf(pageWidth / twInfo.width, pageHeight / twInfo.height);
+  } else {
+    scale = 1.0;
+  }
+  return scale;
+}
 
 /*
  * PSCreateFile generates the output file by using the order of defined
@@ -85,11 +114,7 @@ PSCreateFile(
   fprintf(fp, "\n    grestore\t%% restore graphics state\n\n");
   fclose(fp);
 
-#if 0
-  /* Make frame drawing optional. */
-
   Gdraws_drawFrame(bWidth, vw, tw, title);
-#endif
 
   /* put procedures and script together into OUTPUT.ps */
 
@@ -98,6 +123,16 @@ PSCreateFile(
     return (psError);
   }
   else {
+    fprintf(ofp, "%%!PS-Adobe-2.0\n");
+
+    /* Write a Bounding Box for psfig etc. */
+    XWindowAttributes twInfo;
+    XGetWindowAttributes(dsply, tw, &twInfo);
+    float scale = Gdraws_computeScale(vw, tw);
+    fprintf(ofp, "%%%%BoundingBox: 0 0 %d %d\n",
+            (int) ceilf(scale * twInfo.width),
+            (int) ceilf(scale * twInfo.height));
+
     i = 1;
     while (i < psDrawNo) {  /* loops through each file/procedure */
       if (psData[i].flag) { /* if set, procedure/file is used */
@@ -158,21 +193,25 @@ Gdraws_drawFrame(
   fp = fopen(psData[scriptps].filename, "a");
 
   XGetWindowAttributes(dsply, viewWindow, &vwInfo);
+  XGetWindowAttributes(dsply, titleWindow, &twInfo);
+
+  /* Make frame drawing optional. */
+#if 0
 
   /* draw title window */
 
-  XGetWindowAttributes(dsply, titleWindow, &twInfo);
   fprintf(fp, "\t%s\t%d\t%d\t%d\t%d\ttitle\n", "frameDict",
           twInfo.height - vwInfo.height, twInfo.width, 0, vwInfo.height);
 
   /* draw viewport window */
 
   fprintf(fp, "\t%s\tdrawFrame\n", "frameDict");      /* using Gdraws_setDimension() */
+#endif
 
   /* draw title text */
 
   psData[drawIstrps].flag = yes;
-  fprintf(fp, "\t%s\tloadFont\n\t%d\t(%s) stringwidth pop sub 2 div\n",
+  fprintf(fp, "\t%s\tloadTitleFont\n\t%d\t(%s) stringwidth pop sub 2 div\n",
           "frameDict", twInfo.width, title);
   fprintf(fp, "\t%d\t(%s)\t(%s)\tpsDrawIStr\n", 15, title, "title");
 
@@ -189,47 +228,20 @@ Gdraws_setDimension(
 {
   FILE *fp;
   XWindowAttributes vwInfo, twInfo;
-  float pageWidth, pageHeight, width;
 
   fp = fopen(psData[scriptps].filename, "w");
 
   XGetWindowAttributes(dsply, titleWindow, &twInfo);
   XGetWindowAttributes(dsply, viewWindow, &vwInfo);
-  pageWidth = 575.0;
-  pageHeight = 750.0;
-
-#if 0
-  pageWidth = (float) (DisplayWidth(dsply, scrn) / DisplayWidthMM(dsply, scrn));
-  pageWidth *= 160.0;
-  pageHeight = (float) (DisplayHeight(dsply, scrn) / DisplayHeightMM(dsply, scrn));
-  pageHeight *= 210.0;
-  fprintf(stderr, "%f, %f\n", pageWidth, pageHeight);
-#endif
 
   fprintf(fp, "\n    gsave\t%% save graphics state for clipping path\n\n");
-  if ((vwInfo.height > pageWidth) || (vwInfo.height > pageHeight)) {
-    width = (float) vwInfo.width;
-    if (vwInfo.height > pageWidth) {
-      width = pageWidth / width;
-      fprintf(fp, "\t%f\t%f", width, width);
-    }
-    else {
-      if (vwInfo.height > pageHeight)
-        fprintf(fp, "\t%f\t%f", width, pageHeight / width);
-    }
-  }
-  else {
-    fprintf(fp, "\t%f\t%f", 1.0, 1.0);
-  }
-  fprintf(fp, "\tscale\n\n");
+
+  float scale = Gdraws_computeScale(viewWindow, titleWindow);
+  fprintf(fp, "\t%f\t%f\tscale\n\n", scale, scale);
 
   fprintf(fp, "\t%d\t%d\t%d\tsetDim\n", twInfo.height - vwInfo.height,
           vwInfo.height, vwInfo.width);
 
-  /* Write a Bounding Box for psfig etc. */
-
-  fprintf(fp, "%%%%BoundingBox: 0 0 %d %d\n", vwInfo.height, vwInfo.width);
-
   fprintf(fp, "\tmaxX maxY\t0 0\trectangle\tclip\t%% set clip path\n\n");
   return (fclose(fp));
 }
@@ -353,6 +365,47 @@ GDrawLine(
   return (s);
 }
 
+/*
+ * GColorLine draws a colored line, see GDrawLine
+ */
+
+int
+GColorLine(
+          GC gc,                /* graphics context */
+          Window wid,           /* window id */
+          int x0, int y0, int x1, int y1, int color, int dFlag)
+{
+  int s = 0;
+
+  switch (dFlag) {
+  case Xoption:
+    XSetForeground(dsply, gc, (unsigned long) color);
+    XDrawLine(dsply, wid, gc, x0, y0, x1, y1);
+    break;
+  case PSoption:
+    {
+      PSsetrgbcolor(color);
+      FILE *fp;
+
+      if ((fp = fopen(psData[scriptps].filename, "a")) == NULL) {
+        fprintf(stderr, "GColorLine cannot open %s\n",
+                psData[scriptps].filename);
+        return (psError);
+      }
+
+      psData[drawlineps].flag = yes;      /* sets procedure flag */
+      fprintf(fp, "\t%d\t%d\t%d\t%d\tpsColorLine\n",
+              x1, y1, x0, y0);
+      s = fclose(fp);
+    }
+    break;
+  default:
+    fprintf(stderr, "GColorLine request (%d) not implemented yet.\n",
+            dFlag);
+    return (psError);
+  }
+  return (s);
+}
 
 
 
@@ -415,6 +468,7 @@ int
 GDrawPoint(
            Window wid,          /* window id */
            GC gc,               /* graphics context */
+           int color,           /* color is represented as 0xRRGGBB */
            int x0, int y0, int dFlag)
 {
   int s = 0;
@@ -425,6 +479,8 @@ GDrawPoint(
     break;
   case PSoption:
     {
+      PSsetrgbcolor(color);
+
       FILE *fp;
 
       if ((fp = fopen(psData[scriptps].filename, "a")) == NULL) {
@@ -434,8 +490,8 @@ GDrawPoint(
       }
 
       psData[drawpointps].flag = yes;     /* sets procedure flag */
-      fprintf(fp, "\t%s\t%d\t%d\t%d\t%d\tpsDrawPoint\n",
-              PSfindGC(gc), x0, y0, x0 + 1, y0 + 1);
+      fprintf(fp, "\t%d\t%d\t%d\t%d\tpsDrawPoint\n",
+              x0, y0, x0 + 1, y0 + 1);
       s = fclose(fp);
     }
     break;
@@ -670,6 +726,52 @@ GFillArc(
   return (s);
 }
 
+/*
+ * Draws and fills an arc with color; see GFillArc
+ */
+
+int
+GColorFillArc(
+         GC gc,                 /* graphics context */
+         Window wid,            /* window id */
+         int x, int y,
+         unsigned int wdth, unsigned int hght,
+         int ang1, int ang2, int color, int dFlag)
+{
+  int s = 0;
+
+  switch (dFlag) {
+  case Xoption:                   /* angle: times 64 already */
+    XSetForeground(dsply, gc, (unsigned long) color);
+    XFillArc(dsply, wid, gc, x, y, wdth, hght, ang1, ang2);
+    break;
+  case PSoption:
+    {
+      PSsetrgbcolor(color);
+
+      FILE *fp;
+
+      if ((fp = fopen(psData[scriptps].filename, "a")) == NULL) {
+        fprintf(stderr, "GColorFillArc cannot open %s\n",
+                psData[scriptps].filename);
+        return (psError);
+      }
+
+      psData[fillarcps].flag = yes;       /* sets procedure flag */
+      fprintf(fp, "\t%d %d\t%d %d\t%d %d\t%d %d\tpsColorFillArc\n",
+              x, y, hght, wdth, ang1 / 64, ang2 / 64,
+              x + wdth / 2, y + hght / 2);
+      s = fclose(fp);
+    }
+    break;
+  default:
+    fprintf(stderr, "GColorFillArc request (%d) not implemented yet\n",
+            dFlag);
+    return (psError);
+  }
+  return (s);
+}
+
 /*
  * Initializes the path and files to be used.
  */
@@ -888,6 +990,30 @@ PSfindGC(GC gc)
     return (curGC->GCchar);
 }
 
+
+/* Set a RGB color in postscript, the color is represented as 0xRRGGBB */
+
+int
+PSsetrgbcolor(int color)
+{
+  int s = 0;
+  FILE *fp;
+
+  if ((fp = fopen(psData[scriptps].filename, "a")) == NULL) {
+    fprintf(stderr, "PSsetrgbcolor cannot open %s\n",
+            psData[scriptps].filename);
+    return (psError);
+  }
+
+  float r = ((color & 0xFF0000) >> 16) / 255.0;
+  float g = ((color & 0x00FF00) >> 8) / 255.0;
+  float b = (color & 0x0000FF) / 255.0;
+  fprintf(fp, "\t%f\t%f\t%f\tsetrgbcolor\n", r, g, b);
+
+  s = fclose(fp);
+  return (s);
+}
+
 /*
  * Sets foreground color; see XSetForeground
  */
