@@ -58,7 +58,6 @@ HTReadBitmapFile(Display *display,int screen,char * filename,
     XImage *image;
     FILE *fd;
     char Line[256], Buff[256];
-    int num_chars;
     char *ptr;
     int rch;
     int version;
@@ -134,7 +133,6 @@ HTReadBitmapFile(Display *display,int screen,char * filename,
     (image)->bytes_per_line = chars_line = (*width + 7) / 8;
     file_chars_line = chars_line + padding;
 
-    num_chars = chars_line * (*height);
     file_chars = file_chars_line * (*height);
     (image)->data = (char *) halloc((image)->bytes_per_line * (image)->height,
                                     "Read Pixmap--Image data");
