@@ -853,398 +853,3 @@ close_client(int pid)
     }
 }
 
-
-
-char *
-print_source_to_string(TextNode *command)
-{
-    int len = 0;
-
-    print_source_to_string1(command, &len);
-    p2sBuf = resizeBuffer(len, p2sBuf, &p2sBufSize);
-    return print_source_to_string1(command, NULL);
-}
-char *
-print_source_to_string1(TextNode *command,int * sizeBuf)
-{
-    char *c = p2sBuf;
-    char *s;
-    InputItem *item;
-    LineStruct *curr_line;
-    int lcount;
-    InputBox *box;
-    int num_spaces;
-    int count;
-    TextNode *node;
-
-    /*
-        print out HyperDoc source for what you see
-     */
-
-    for (node = command; node != NULL;) {
-        switch (node->type) {
-          case Newline:
-            storeString("\\newline\n");
-            node = node->next;
-            break;
-          case Par:
-            storeString("\n\n");
-            node = node->next;
-            break;
-          case Indentrel:
-            storeString("\\indentrel{");
-            storeString(node->data.node->data.text);
-            storeChar('}');
-            node = node->next;
-            break;
-          case Tab:
-            storeString("\\tab{");
-            storeString(node->data.node->data.text);
-            storeChar('}');
-            node = node->next;
-            break;
-          case Ifcond:
-            if (check_condition(node->data.ifnode->cond))
-                node = node->data.ifnode->thennode;
-            else
-                node = node->data.ifnode->elsenode;
-            break;
-          case Endarg:
-          case Endspadsrc:
-          case Endpix:
-          case Endbutton:
-            storeChar('}');
-            node = node->next;
-            break;
-          case Endverbatim:
-          case Endif:
-          case Fi:
-          case Endmacro:
-          case Endparameter:
-          case Rbrace:
-            node = node->next;
-            break;
-          case Punctuation:
-
-            /*
-             * Simply copy the piece of text
-             */
-            if (node->space & FRONTSPACE) { storeChar(' '); }
-            for (s = node->data.text; *s; s++) { storeChar(*s); }
-            node = node->next;
-            break;
-          case WindowId:
-            storeString("\\windowid ");
-            node = node->next;
-            break;
-          case Verbatim:
-          case Spadsrctxt:
-            if (node->space) { storeChar(' '); }
-            for (s = node->data.text; *s; s++) { storeChar(*s); }
-            node = node->next;
-            break;
-          case Dash:
-          case Rsquarebrace:
-          case Lsquarebrace:
-          case Word:
-            if (node->space) { storeChar(' '); }
-            for (s = node->data.text; *s; s++) { storeChar(*s); }
-            node = node->next;
-            break;
-          case BoxValue:
-            box = (InputBox *) hash_find(gWindow->page->box_hash, node->data.text);
-            if (box == NULL) {
-                fprintf(stderr, "Print_to_string:Box %s Has no symbol table entry\n",
-                        node->data.text);
-                exit(-1);
-            }
-            storeChar(' ');
-            if (box->picked) {
-                storeChar('t');
-            }
-            else {
-                storeChar('n');
-                storeChar('i');
-                storeChar('l');
-            }
-            node = node->next;
-            break;
-          case StringValue:
-            item = return_item(node->data.text);
-            if (item != NULL) {
-                if (node->space) {  storeChar(' '); }
-                curr_line = item->lines;
-                while (curr_line != NULL) {
-                    for (lcount = 0, s = curr_line->buffer;
-                         *s && lcount < item->size;
-                         s++, lcount++) {
-                        storeChar(funnyUnescape(*s));
-                    }
-                    if (curr_line->len <= item->size && curr_line->next)
-                        storeChar('\n');
-                    curr_line = curr_line->next;
-                }
-            }
-            else if ((box = (InputBox *) hash_find(gWindow->page->box_hash,
-                                                node->data.text)) != NULL) {
-                if (node->space) { storeChar(' '); }
-                if (box->picked) {
-                    storeChar('t');
-                }
-                else {
-                    storeChar('n');
-                    storeChar('i');
-                    storeChar('l');
-                }
-            }
-            else {
-                fprintf(stderr, "Error, Symbol %s has no symbol table entry\n",
-                        node->data.text);
-                exit(-1);
-            }
-            node = node->next;
-            break;
-          case Space:
-            num_spaces = (node->data.node != NULL ?
-                          atoi(node->data.node->data.text) : 1);
-            for (count = 0; count < num_spaces; count++)
-                storeChar(' ');
-            node = node->next;
-            break;
-          case Emphasize:
-            storeString("\\em ");
-            node = node->next;
-            break;
-          case BoldFace:
-            storeString("\\bf ");
-            node = node->next;
-            break;
-          case Sl:
-            storeString("\\it ");
-            node = node->next;
-            break;
-          case Rm:
-            storeString("\\rm ");
-            node = node->next;
-            break;
-          case It:
-            storeString("\\it ");
-            node = node->next;
-            break;
-          case Tt:
-            storeString("\\tt ");
-            node = node->next;
-            break;
-          case Group:
-/* skip {} */
-            if (node->next->type==Endgroup){
-               node=node->next->next;
-               break;
-                }
-            storeChar('{');
-            node = node->next;
-            break;
-          case Endgroup:
-            storeChar('}');
-            node = node->next;
-            break;
-          case Box:
-            storeString("\\box{");
-            node = node->next;
-            break;
-          case Endbox:
-            storeChar('}');
-            node = node->next;
-            break;
-          case Center:
-            storeString("\\center{");
-            node = node->next;
-            break;
-          case Endcenter:
-            storeString("}");
-            storeChar('\n');
-            node = node->next;
-            break;
-          case Titlenode:
-          case Endtitle:
-            node = node->next;
-            break;
-          case Bound:
-            {
-                TextNode *n2 = node->data.node;
-
-                storeString("\\bound{");
-                for (; n2->type != Endarg; n2 = n2->next) {
-                    if (n2->type == Word) {
-                        storeString(n2->data.text);
-                        storeChar(' ');
-                        }
-                    }
-                storeChar('}');
-            }
-            node = node->next;
-            break;
-          case Free:
-            {
-                TextNode *n2 = node->data.node;
-
-                storeString("\\free{");
-                for (; n2->type != Endarg; n2 = n2->next) {
-                    if (n2->type == Word) {
-                        storeString(n2->data.text);
-                        storeChar(' ');
-                        }
-                    }
-                storeChar('}');
-                }
-            node = node->next;
-            break;
-          case Macro:
-            storeChar(' ');
-            node = node->next;
-            break;
-          case Pound:
-            if (node->space) { storeChar(' '); }
-            node = node->next;
-            break;
-          case Indent:
-            num_spaces = (node->data.node != NULL ?
-                          atoi(node->data.node->data.text) : 1);
-            for (count = 0; count < num_spaces; count++)
-                storeChar(' ');
-            node = node->next;
-            break;
-          case Inputbitmap:
-            storeString("\\inputbitmap{");
-            storeString(node->data.text);
-            storeString("}\n");
-            node = node->next;
-            break;
-          case Endscrolling:
-            storeString("\\end{scroll}\n");
-            node = node->next;
-            break;
-          case Scrollingnode:
-            storeString("\\begin{scroll}\n");
-            storeString("% This is the scrolling area\n");
-            node = node->next;
-            break;
-          case Horizontalline:
-            storeString("\\horizontalline\n");
-            node = node->next;
-            break;
-          case Endtable:
-            storeChar('}');
-            node = node->next;
-            break;
-          case Table:
-            storeString("\\table{");
-            node = node->next;
-            break;
-          case Tableitem:
-            storeChar('{');
-            node = node->next;
-            break;
-          case Endtableitem:
-            storeChar('}');
-            node = node->next;
-            break;
-          case Beginitems:
-            storeString("\\begin{items}");
-            node = node->next;
-            break;
-          case Item:
-            storeString("\n\\item");
-            node = node->next;
-            break;
-          case Enditems:
-            storeString("\n\\end{items}");
-            node = node->next;
-            break;
-/*** LINKS ***/
-/* all these guys are ended by Endbutton
-we close the brace then */
-          case Spadlink:
-            storeString("\\fauxspadlink{");
-            node = node->next;
-            break;
-          case Unixlink:
-            storeString("\\fauxunixlink{");
-            node = node->next;
-            break;
-          case Lisplink:
-            storeString("\\fauxlisplink{");
-            node = node->next;
-            break;
-          case Link:
-            storeString("\\fauxlink{");
-            node = node->next;
-            break;
-          case LispDownLink:
-            storeString("\\fauxlispdownlink{");
-            node = node->next;
-            break;
-          case LispMemoLink:
-            storeString("\\fauxlispmemolink{");
-            node = node->next;
-            break;
-          case Memolink:
-            storeString("\\fauxmemolink{");
-            node = node->next;
-            break;
-          case Windowlink:
-            storeString("\\fauxwindowlink{");
-            node = node->next;
-            break;
-          case Downlink:
-            storeString("\\fauxdownlink{");
-            node = node->next;
-            break;
-/** END OF LINKS **/
-          case Unixcommand:
-            storeString("\\unixcommand{");
-            node = node->next;
-            break;
-          case Lispcommand:
-            storeString("\\lispcommand{");
-            node = node->next;
-            break;
-          case Spadgraph:
-            storeString("\\spadgraph{");
-            node = node->next;
-            break;
-          case Spadcommand:
-            storeString("\\spadcommand{");
-            node = node->next;
-            break;
-          case Endspadcommand:
-            storeChar('}');
-            node = node->next;
-            break;
-          case Footernode:
-            storeString("% This is the footer\n");
-            node = node->next;
-            break;
-          case Endfooter:
-            storeString("% This is the end of the footer\n");
-            node = node->next;
-            break;
-          case Endheader:
-            storeString("% This is the end of the header\n");
-            node = node->next;
-            break;
-          case Headernode:
-            storeString("% This is the header\n");
-            node = node->next;
-            break;
-          default:
-            fprintf(stderr,
-                    "Print_source_to_string: Unrecognized Keyword Type %d\n",
-                    node->type);
-            node=node->next;
-            break;
-        }
-    }
-    storeChar('\0');
-    return p2sBuf;
-}
