@@ -52,8 +52,6 @@
 
 (defmacro def-boot-val (p val where) `(defparameter ,p ,val ,where))
 
-(def-boot-val |$timerTicksPerSecond| INTERNAL-TIME-UNITS-PER-SECOND
-    "scale for get_run_time")
 (def-boot-val $boxString
   (concatenate 'string (list (code-char #x1d) (code-char #xe2)))
   "this string of 2 chars displays as a box")
@@ -66,50 +64,9 @@
   "switch back into normal font")
 (def-boot-val |$BreakMode| '|query|                 "error.boot")
 
-
-(def-boot-var |$compUniquelyIfTrue|                 "Compiler>Compiler.boot")
-(def-boot-val |$currentLine|    ""          "current input line for history")
-
-(def-boot-var |$exitMode|                           "???")
-(def-boot-var |$exitModeStack|                      "???")
-
-(def-boot-var |$fromSpadTrace|                      "Interpreter>Trace.boot")
-
-(def-boot-val |$genSDVar| 0         "counter for genSomeVariable" )
-
-(def-boot-var |$insideCapsuleFunctionIfTrue|        "???")
-(def-boot-var |$insideCategoryIfTrue|               "???")
-(def-boot-var |$insideFunctorIfTrue|                "???")
-(def-boot-var |$insideWhereIfTrue|                  "???")
-
-(def-boot-var |$leaveLevelStack|                    "???")
-(def-boot-var |$libFile|                            "Compiler>LispLib.boot")
-(def-boot-val $LISPLIB nil                  "whether to produce a lisplib or not")
-(def-boot-var |$lisplibForm|                        "Compiler>LispLib.boot")
-(def-boot-var |$lisplibKind|                        "Compiler>LispLib.boot")
-(def-boot-var |$lisplibModemapAlist|                "Compiler>LispLib.boot")
-(def-boot-var |$lisplibModemap|                     "Compiler>LispLib.boot")
-(def-boot-var |$lisplibOperationAlist|              "Compiler>LispLib.boot")
-
-(def-boot-var |$mapSubNameAlist|                    "Interpreter>Trace.boot")
-(def-boot-var |$mathTrace|                          "Interpreter>Trace.boot")
-(def-boot-var |$mathTraceList|              "Controls mathprint output for )trace.")
-
-(def-boot-var |$postStack|                          "???")
-(def-boot-var |$previousTime|                       "???")
-(def-boot-val |$printLoadMsgs|  nil          "Interpreter>SetVarT.boot")
 (def-boot-var |$reportBottomUpFlag|                 "Interpreter>SetVarT.boot")
-(def-boot-var |$returnMode|                         "???")
-(def-boot-var |$semanticErrorStack|                 "???")
 (def-boot-val |$SetFunctions| nil  "checked in SetFunctionSlots")
 
-(def-boot-var |$topOp|                             "See displayPreCompilationErrors")
-(def-boot-var |$tracedSpadModemap|                  "Interpreter>Trace.boot")
-(def-boot-var |$traceletFunctions|                  "???")
-
-(def-boot-var |$warningStack|                       "???")
-(def-boot-val |$whereList| () "referenced in format boot formDecl2String")
-
 (def-boot-val |$inputPromptType| '|step|  "checked in MKPROMPT")
 (def-boot-val |$IOindex| 0                 "step counter")
 
@@ -127,152 +84,35 @@
 
 ; Ordering
 
-(DEFUN ?ORDER (U V)
+(DEFUN |lt_sexp| (U V)
   "Multiple-type ordering relation."
 ;;; Result negated compared to LEXGREATERP and GGREATERP
 ;;;   Order of types: nil number symbol string vector cons"
-  (COND ((NULL U))
+  (COND ((EQ U V) NIL)
+        ((NULL U) T)
         ((NULL V) NIL)
         ((ATOM U)
          (if (ATOM V)
              (COND ((NUMBERP U) (if (NUMBERP V) (> V U) T))
                    ((NUMBERP V) NIL)
-                   ((IDENTP U) (AND (IDENTP V) (string> (SYMBOL-NAME V) (SYMBOL-NAME U))))
+                   ((IDENTP U) (AND (IDENTP V)
+                                    (string> (SYMBOL-NAME V) (SYMBOL-NAME U))
+                                    T))
                    ((IDENTP V) NIL)
-                   ((STRINGP U) (AND (STRINGP V) (string> V U)))
+                   ((STRINGP U) (AND (STRINGP V) (string> V U) T))
                    ((STRINGP V) NIL)
                    ((BREAK))
-                   ((AND (VECP U) (VECP V))
-                    (AND (> (SIZE V) (SIZE U))
-                         (DO ((I 0 (1+ I)))
-                             ((> I (MAXINDEX U)) 'T)
-                           (COND ((NOT (EQUAL (ELT U I) (ELT V I)))
-                                  (RETURN (?ORDER (ELT U I) (ELT V I))))))))
                    ((croak "Do not understand")))
                T))
         ((ATOM V) NIL)
-        ((EQUAL U V))
         ((EQUAL (CAR U) (CAR V))
-           (?ORDER (CDR U) (CDR V)))
-        ((?ORDER (CAR U) (CAR V)))
+           (|lt_sexp| (CDR U) (CDR V)))
+        ((|lt_sexp| (CAR U) (CAR V)))
 ))
 
-(DEFUN LEXGREATERP (COMPERAND-1 COMPERAND-2)
-    ;;  "Order of types: pair NIL vec string symbol num fbpi other"
-    (COND
-      ((EQ COMPERAND-1 COMPERAND-2) NIL)
-      ((consp COMPERAND-1)
-        (COND
-          ( (consp COMPERAND-2)
-            (COND
-              ( (EQUAL (qcar COMPERAND-1) (qcar COMPERAND-2))
-                (LEXGREATERP (qcdr COMPERAND-1) (qcdr COMPERAND-2)) )
-              ( (LEXGREATERP (qcar COMPERAND-1) (qcar COMPERAND-2)) ) ) )
-          ('else t)))
-      ((consp COMPERAND-2) NIL)
-      ((NULL COMPERAND-1) 'T )
-      ((NULL COMPERAND-2) NIL)
-      ((VECP COMPERAND-1)
-        (BREAK))
-      ((VECP COMPERAND-2) (BREAK))
-      ((stringp COMPERAND-1)
-        (COND
-          ((stringp COMPERAND-2)
-            (STRING-GREATERP COMPERAND-1 COMPERAND-2) )
-          ('else t)))
-      ((stringp COMPERAND-2) NIL)
-      ((symbolp COMPERAND-1)
-        (COND
-          ((symbolp COMPERAND-2)
-            (STRING-GREATERP (symbol-name COMPERAND-1) (symbol-name COMPERAND-2)) )
-          ('else t)))
-      ((symbolp COMPERAND-2) NIL )
-      ((numberp COMPERAND-1)
-        (COND
-          ( (numberp COMPERAND-2)
-            (> COMPERAND-1 COMPERAND-2) )
-          ('else t)))
-      ((numberp COMPERAND-2) NIL)
-      ((CHARACTERP COMPERAND-1)
-        (COND
-          ((CHARACTERP COMPERAND-2)
-            (CHAR-GREATERP COMPERAND-1 COMPERAND-2) )
-          ('else t)))
-      ((CHARACTERP COMPERAND-2) NIL )
-      (BREAK)
-      ((> (SXHASH COMPERAND-1) (SXHASH COMPERAND-2)))))
+(defun GLESSEQP (X Y) (|lt_sexp| X Y))
 
-(DEFUN GGREATERP (COMPERAND-1 COMPERAND-2)
-    ;;  "Order of types: symbol pair NIL vec string num fbpi other"
-    (COND
-      ((EQ COMPERAND-1 COMPERAND-2) NIL)
-      ((symbolp COMPERAND-1)
-        (COND
-          ((symbolp COMPERAND-2)
-            (CGREATERP (symbol-name COMPERAND-1) (symbol-name COMPERAND-2)) )
-          ('else t)))
-      ((symbolp COMPERAND-2) NIL )
-      ((consp COMPERAND-1)
-        (COND
-          ( (consp COMPERAND-2)
-            (COND
-              ( (EQUAL (qcar COMPERAND-1) (qcar COMPERAND-2))
-                (GGREATERP (qcdr COMPERAND-1) (qcdr COMPERAND-2)) )
-              ( (GGREATERP (qcar COMPERAND-1) (qcar COMPERAND-2)) ) ) )
-          ('else t)))
-      ((consp COMPERAND-2) NIL)
-      ((NULL COMPERAND-1) 'T )
-      ((NULL COMPERAND-2) NIL)
-      ((VECP COMPERAND-1)
-        (COND
-          ((VECP COMPERAND-2) (VGREATERP COMPERAND-1 COMPERAND-2) )
-          ('else t))
-      )
-      ((VECP COMPERAND-2) NIL)
-      ((stringp COMPERAND-1)
-        (COND
-          ((stringp COMPERAND-2)
-            (CGREATERP COMPERAND-1 COMPERAND-2) )
-          ('else t)))
-      ((stringp COMPERAND-2) NIL)
-      ((numberp COMPERAND-1)
-        (COND
-          ( (numberp COMPERAND-2)
-            (> COMPERAND-1 COMPERAND-2) )
-          ('else t)))
-      ((numberp COMPERAND-2) NIL)
-      ((CHARACTERP COMPERAND-1)
-        (COND
-          ((CHARACTERP COMPERAND-2)
-            (CHAR> COMPERAND-1 COMPERAND-2) )
-          ('else t)))
-      ((CHARACTERP COMPERAND-2) NIL )
-      ((> (SXHASH COMPERAND-1) (SXHASH COMPERAND-2)))))
-
-;;; Would like to remove this but is is used in PartialFraction
-(DEFUN VGREATERP (VECTOR-COMPERAND-1 VECTOR-COMPERAND-2)
-  (declare (simple-vector vector-comperand-1 vector-comperand-2))
-    (PROG ((L1 (length VECTOR-COMPERAND-1))
-           (L2 (length VECTOR-COMPERAND-2))
-           (I -1)
-           T1 T2)
-     (declare (fixnum i l1 l2) )
-  LP  (setq i (1+ i))
-      (COND
-        ((EQL L1 I) (RETURN NIL))
-        ((EQL L2 I) (RETURN 'T)))
-      (COND
-        ((EQUAL
-            (SETQ T1 (svref VECTOR-COMPERAND-1 I))
-            (SETQ T2 (svref VECTOR-COMPERAND-2 I)))
-          (GO LP)))
-      (RETURN (GGREATERP T1 T2)) ) )
-
-(defvar SORTGREATERP #'GGREATERP "default sorting predicate")
-
-(defun GLESSEQP (X Y) (NOT (GGREATERP X Y)))
-
-(defun LEXLESSEQP (X Y) (NOT (LEXGREATERP X Y)))
+(defun LEXLESSEQP (X Y) (|lt_sexp| X Y))
 
 
 ; 10.3 Creating Symbols
@@ -297,20 +137,6 @@
 
 (DEFUN LASTATOM (L) (if (ATOM L) L (LASTATOM (CDR L))))
 
-(defun DROP (N X &aux m)
-  "Return a pointer to the Nth cons of X, counting 0 as the first cons."
-  (COND ((EQL N 0) X)
-        ((> N 0) (DROP (1- N) (CDR X)))
-        ((>= (setq m (+ (length x) N)) 0) (take m x))
-        ((CROAK (list "Bad args to DROP" N X)))))
-
-(DEFUN TAKE (N X &aux m)
-  "Returns a list of the first N elements of list X."
-  (COND ((EQL N 0) NIL)
-        ((> N 0) (CONS (CAR X) (TAKE (1- N) (CDR X))))
-        ((>= (setq m (+ (length x) N)) 0) (DROP m x))
-        ((CROAK (list "Bad args to DROP" N X)))))
-
 ; 15.4 Substitution of Expressions
 
 ;; needed for substNames (always copy)
@@ -342,13 +168,6 @@
 
 (defun |set_difference| (l1 l2) (set-difference l1 l2 :test #'equal))
 
-
-(DEFUN PREDECESSOR (TL L)
-  "Returns the sublist of L whose CDR is EQ to TL."
-  (COND ((ATOM L) NIL)
-        ((EQ TL (CDR L)) L)
-        ((PREDECESSOR TL (CDR L)))))
-
 (defun remdup (l) (remove-duplicates l :test #'equalp))
 
 ; 15.6 Association Lists
@@ -423,16 +242,10 @@
 
 ; 22.3.1 Output to Character Streams
 
-(defvar |$sayBrightlyStream| nil "if not nil, gives stream for sayBrightly output")
-
 (defun |get_lisp_std_out| () *standard-output*)
 
 (defun |get_lisp_error_out| () *error-output*)
 
-(defvar |$fortranOutputStream|)
-
-(defvar |$highlightAllowed| nil "Used in BRIGHTPRINT and is a )set variable.")
-
 (defvar |$highlightFontOn| (concat " " |$boldString|)
                      "switch to highlight font")
 (defvar |$highlightFontOff| (concat |$normalString| " ")
