@@ -85,7 +85,7 @@
 
 ; **** X. Random tables
 
-(MAKEPROP 'TAG '|Led| '(TAG TAG 122 121))
+(MAKEPROP '|~>| '|Led| '(|~>| |~>| 122 121))
 (MAKEPROP 'EQUATNUM '|Nud| '(|dummy| |dummy| 0 0))
 (MAKEPROP 'EQUATNUM '|Led| '(|dummy| |dummy| 10000 0))
 (MAKEPROP 'LET '|Led| '(|:=| LET 125 124))
@@ -101,12 +101,10 @@
       :initial-contents initialvalue)))
 
 (defun |knownEqualPred| (dom)
-  (let ((fun (|compiledLookup| '= '((|Boolean|) $ $) dom)))
+  (let ((fun (|compiledLookup| '= '((|Boolean|) % %) dom)))
     (if fun (get (bpiname (car fun)) '|SPADreplace|)
       nil)))
 
 (defun |hashable| (dom)
   (memq (|knownEqualPred| dom)
-        #-Lucid '(EQ EQL EQUAL)
-        #+Lucid '(EQ EQL EQUAL EQUALP)
-        ))
+        '(EQ EQL EQUAL)))
