@@ -605,9 +605,8 @@ sock_send_floats(int purpose, double  *vals, int num)
 double
 get_float(Sock *sock)
 {
-  int val;
   double num = -1.0;
-  val = fill_buf(sock, (char *)&num, sizeof(double), "double");
+  fill_buf(sock, (char *)&num, sizeof(double), "double");
 #ifdef DEBUG
   fprintf(stderr,"get_float: received %f\n",num);
 #endif
